@@ -1,9 +1,16 @@
+"""
+$description Live TV channels from DR, a Danish public, state-owned broadcaster.
+$url dr.dk
+$type live
+$region Denmark
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
