@@ -1,11 +1,17 @@
+"""
+$description Live TV channels and video on-demand service from RTP, a Portuguese public, state-owned broadcaster.
+$url rtp.pt/play
+$type live, vod
+$region Portugal
+"""
+
 import re
 from base64 import b64decode
 from urllib.parse import unquote
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import useragents, validate
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
 
 
 @pluginmatcher(re.compile(
@@ -37,13 +43,15 @@ class RTPPlay(Plugin):
             validate.all(
                 validate.get("obfuscated"),
                 str,
-                validate.transform(lambda arr: unquote("".join(parse_json(arr)))),
+                validate.parse_json(),
+                validate.transform(lambda arr: unquote("".join(arr))),
                 validate.url()
             ),
             validate.all(
                 validate.get("obfuscated_b64"),
                 str,
-                validate.transform(lambda arr: unquote("".join(parse_json(arr)))),
+                validate.parse_json(),
+                validate.transform(lambda arr: unquote("".join(arr))),
                 validate.transform(lambda b64: b64decode(b64).decode("utf-8")),
                 validate.url()
             )
