@@ -3,7 +3,6 @@ import datetime
 import logging
 import math
 import re
-import time
 from collections import defaultdict, namedtuple
 from contextlib import contextmanager
 from itertools import count, repeat
@@ -45,22 +44,6 @@ def freeze_timeline(mpd):
     mpd.timelines = timelines
 
 
-@contextmanager
-def sleeper(duration):
-    s = time.time()
-    yield
-    time_to_sleep = duration - (time.time() - s)
-    if time_to_sleep > 0:
-        time.sleep(time_to_sleep)
-
-
-def sleep_until(walltime):
-    c = datetime.datetime.now(tz=utc)
-    time_to_wait = (walltime - c).total_seconds()
-    if time_to_wait > 0:
-        time.sleep(time_to_wait)
-
-
 class MPDParsers:
     @staticmethod
     def bool_str(v):
