@@ -1,3 +1,4 @@
+import concurrent.futures
 import logging
 import subprocess
 import sys
@@ -7,15 +8,31 @@ from shutil import which
 from streamlink import StreamError
 from streamlink.compat import devnull
 from streamlink.stream.stream import Stream, StreamIO
-from streamlink.utils import NamedPipe
+from streamlink.utils.named_pipe import NamedPipe, NamedPipeBase
 
 log = logging.getLogger(__name__)
 
 
 class MuxedStream(Stream):
+    """
+    Muxes multiple streams into one output stream.
+    """
+
     __shortname__ = "muxed-stream"
 
-    def __init__(self, session, *substreams, **options):
+    def __init__(
+        self,
+        session,
+        *substreams: Stream,
+        **options
+    ):
+        """
+        :param streamlink.Streamlink session: Streamlink session instance
+        :param substreams: Video and/or audio streams
+        :param options: Additional keyword arguments passed to :class:`ffmpegmux.FFMPEGMuxer`.
+                        Subtitle streams need to be set via the ``subtitles`` keyword.
+        """
+
         super().__init__(session)
         self.substreams = substreams
         self.subtitles = options.pop("subtitles", {})
@@ -58,8 +75,8 @@ class FFMPEGMuxer(StreamIO):
     DEFAULT_AUDIO_CODEC = "copy"
 
     @staticmethod
-    def copy_to_pipe(self, stream, pipe):
-        log.debug("Starting copy to pipe: {0}".format(pipe.path))
+    def copy_to_pipe(stream: StreamIO, pipe: NamedPipeBase):
+        log.debug(f"Starting copy to pipe: {pipe.path}")
         pipe.open()
         while not stream.closed:
             try:
@@ -69,13 +86,13 @@ class FFMPEGMuxer(StreamIO):
                 else:
                     break
             except OSError:
-                log.error("Pipe copy aborted: {0}".format(pipe.path))
-                return
+                log.error(f"Pipe copy aborted: {pipe.path}")
+                break
         try:
             pipe.close()
         except OSError:  # might fail closing, but that should be ok for the pipe
             pass
-        log.debug("Pipe copy complete: {0}".format(pipe.path))
+        log.debug(f"Pipe copy complete: {pipe.path}")
 
     def __init__(self, session, *streams, **options):
         if not self.is_usable(session):
@@ -86,7 +103,7 @@ class FFMPEGMuxer(StreamIO):
         self.streams = streams
 
         self.pipes = [NamedPipe() for _ in self.streams]
-        self.pipe_threads = [threading.Thread(target=self.copy_to_pipe, args=(self, stream, np))
+        self.pipe_threads = [threading.Thread(target=self.copy_to_pipe, args=(stream, np))
                              for stream, np in
                              zip(self.streams, self.pipes)]
 
@@ -167,10 +184,13 @@ class FFMPEGMuxer(StreamIO):
             self.process.stdout.close()
 
             # close the streams
+            futures = []
+            executor = concurrent.futures.ThreadPoolExecutor()
             for stream in self.streams:
                 if hasattr(stream, "close") and callable(stream.close):
-                    stream.close()
+                    futures.append(executor.submit(stream.close))
 
+            concurrent.futures.wait(futures, return_when=concurrent.futures.ALL_COMPLETED)
             log.debug("Closed all the substreams")
 
         if self.close_errorlog:
